Config

Struct Config 

pub struct Config { /* private fields */ }
Configuration settings for the Camera interface.

Implementations

Source

impl Config

pub fn with_frequency(self, frequency: Rate) -> Self

Assign the given value to the frequency field.

pub fn frequency(&self) -> Rate

The pixel clock frequency for the camera interface.

pub fn with_enable_2byte_mode(self, enable_2byte_mode: bool) -> Self

Assign the given value to the enable_2byte_mode field.

pub fn enable_2byte_mode(&self) -> bool

Enable 16 bit mode (instead of 8 bit).

pub fn with_byte_order(self, byte_order: ByteOrder) -> Self

Assign the given value to the byte_order field.

pub fn byte_order(&self) -> ByteOrder

The byte order for the camera data.

pub fn with_bit_order(self, bit_order: BitOrder) -> Self

Assign the given value to the bit_order field.

pub fn bit_order(&self) -> BitOrder

The bit order for the camera data.

pub fn with_vh_de_mode(self, vh_de_mode: VhdeMode) -> Self

Assign the given value to the vh_de_mode field.

pub fn vh_de_mode(&self) -> VhdeMode

Vsync/Hsync or Data Enable Mode

pub fn with_vsync_filter_threshold( self, vsync_filter_threshold: VsyncFilterThreshold, ) -> Self

Assign the given value to the vsync_filter_threshold field.

pub fn with_vsync_filter_threshold_none(self) -> Self

Set the value of vsync_filter_threshold to None.

pub fn vsync_filter_threshold(&self) -> Option<VsyncFilterThreshold>

The Vsync filter threshold.

pub fn with_eof_mode(self, eof_mode: EofMode) -> Self

Assign the given value to the eof_mode field.

pub fn eof_mode(&self) -> EofMode

Conditions under which Camera should emit a SUC_EOF to the DMA.

pub fn with_line_interrupt(self, line_interrupt: u8) -> Self

Assign the given value to the line_interrupt field.

pub fn with_line_interrupt_none(self) -> Self

Set the value of line_interrupt to None.

pub fn line_interrupt(&self) -> Option<u8>

If set, the line interrupt is enabled and will be triggered when the number of received lines reaches this value + 1.

This is a 7 bit value which means a max of 128 lines.

pub fn with_invert_vsync(self, invert_vsync: bool) -> Self

Assign the given value to the invert_vsync field.

pub fn invert_vsync(&self) -> bool

Invert VSYNC signal, valid in high level.

pub fn with_invert_hsync(self, invert_hsync: bool) -> Self

Assign the given value to the invert_hsync field.

pub fn invert_hsync(&self) -> bool

Invert HSYNC signal, valid in high level.

pub fn with_invert_h_enable(self, invert_h_enable: bool) -> Self

Assign the given value to the invert_h_enable field.

pub fn invert_h_enable(&self) -> bool

Invert H_ENABLE signal (Also known as “Data Enable”), valid in high level.

pub fn with_invert_pixel_clock(self, invert_pixel_clock: bool) -> Self

Assign the given value to the invert_pixel_clock field.

pub fn invert_pixel_clock(&self) -> bool

Invert PCLK signal.